#ifndef _compsat_h_INCLUDED
#define _compsat_h_INCLUDED

/*------------------------------------------------------------------------*/

#include <stdlib.h>		/* size_t */
#include <stdio.h>		/* FILE */

/*------------------------------------------------------------------------*/

#define COMPSAT_UNDECIDED	0	/* SAT 200[23] competition */
#define COMPSAT_SATISFIABLE	10	/* SAT 200[23] competition */
#define COMPSAT_UNSATISFIABLE	20	/* SAT 200[23] competition */
#define COMPSAT_TIME_OUT	30
#define COMPSAT_SPACE_OUT	40
#define COMPSAT_DECISION_OUT	50
#define COMPSAT_ABORT		60
#define COMPSAT_EXIT		70

/*------------------------------------------------------------------------*/

typedef struct CompSat CompSat;
typedef struct CompSatArgvIterator CompSatArgvIterator;
typedef struct CompSatArgvIteratorInternal CompSatArgvIteratorInternal;

/*------------------------------------------------------------------------*/

struct CompSatArgvIterator
{
  CompSatArgvIteratorInternal *internal;
  const char *opt;		/* option string */
  const char *arg;		/* argument string or zero */
};

/*------------------------------------------------------------------------*/

CompSat *compsat_new (void);
void compsat_delete (CompSat *);
const char *compsat_id (void);
const char *compsat_version (void);
const char *compsat_copyright (void);
const char *compsat_configuration (void);

/*------------------------------------------------------------------------*/

const char *compsat_res2str (int res);
void compsat_print_assignment (CompSat *, FILE *);
int compsat_sat (CompSat *);

/*------------------------------------------------------------------------*/

int compsat_is_file_option (const char *opt);
void compsat_report_invalid_option (CompSat *,
				    CompSatArgvIterator * it,
				    const char *err);
CompSatArgvIterator *compsat_new_ArgvIterator (CompSat *, int, char **);
int compsat_has_more_elements_ArgvIterator (CompSatArgvIterator *,
					    const char **);
void compsat_delete_ArgvIterator (CompSatArgvIterator *);
const char *compsat_usage (void);
const char *compsat_option (CompSat * compsat, const char *opt,
			    const char *arg);

/*------------------------------------------------------------------------*/

const char *compsat_read (CompSat *, const char *file_name);

/*------------------------------------------------------------------------*/

void compsat_print (CompSat *, FILE *);

double compsat_get_time (void);
double compsat_seconds (CompSat *);
size_t compsat_bytes (CompSat *);
void compsat_print_bytes (FILE *, size_t bytes);
void compsat_print_seconds (FILE *, double seconds);
int compsat_get_verbose_level (CompSat *);
void compsat_set_verbose_level (CompSat *, int);
const char *compsat_prefix (CompSat *);
void compsat_stats (CompSat *, FILE *);
FILE *compsat_out_file (CompSat *);
FILE *compsat_log_file (CompSat *);
FILE *compsat_err_file (CompSat *);

/*------------------------------------------------------------------------*/
#endif
